@@ -8,6 +8,10 @@
   */
 
 
+/**
+  * Build user options for display on "Display Preferences" page
+  *
+  */
 function preview_pane_show_options_do() 
 {
 
@@ -38,7 +42,7 @@ function preview_pane_show_options_do()
    $optpage_data['vals'][1][] = array(
       'name'          => 'previewPane_size',
       'caption'       => _("Message Preview Pane Size"),
-      'type'          => SMOPT_TYPE_STRING,
+      'type'          => SMOPT_TYPE_INTEGER,
       'initial_value' => $previewPane_size,
       'refresh'       => SMOPT_REFRESH_ALL,
       'size'          => SMOPT_SIZE_TINY,
@@ -57,46 +61,100 @@ function preview_pane_show_options_do()
 }
 
 
+/**
+  * Construct button that clears out any preview pane contents.
+  *
+  */
 function preview_pane_clear_pp_button_do()
 {
-   $fixed_archive_mail_plugin_is_in_use_in_SM_1_4_x = 1;
 
-   global $username, $data_dir;
+   global $plugins, $archive_mail_button_has_been_printed,
+          $username, $data_dir;
+
+
+   if (!in_array('archive_mail', $plugins))
+      $fixed_archive_mail_plugin_is_in_use_in_SM_1_4_x = 0;
+   else 
+   {
+
+/* doesn't work due to archive mail functionality not being in a proper function body
+      // trick the archive mail plugin just long enough
+      // to figure out if it has been patched
+      //
+      global $SQM_INTERNAL_VERSION, $archiveMailIsPatchedForPreviewPanePlugin;
+      $tempSMversion = $SQM_INTERNAL_VERSION;
+      $SQM_INTERNAL_VERSION[1] = 5;
+      include_once(SM_PATH . 'plugins/archive_mail/includes/archive_mail_bottom.php');
+      $SQM_INTERNAL_VERSION = $tempSMversion;
+
+      if ($archiveMailIsPatchedForPreviewPanePlugin)
+         $fixed_archive_mail_plugin_is_in_use_in_SM_1_4_x = 1;
+      else
+         $fixed_archive_mail_plugin_is_in_use_in_SM_1_4_x = 0;
+*/
+      $fixed_archive_mail_plugin_is_in_use_in_SM_1_4_x = 1;
+   }
+
 
    if (getPref($data_dir, $username, 'use_previewPane', 0) == 1) 
    {
 
-      if ($fixed_archive_mail_plugin_is_in_use_in_SM_1_4_x)
+      if ($fixed_archive_mail_plugin_is_in_use_in_SM_1_4_x 
+       && !$archive_mail_button_has_been_printed)
+         include_once(SM_PATH . 'plugins/archive_mail/includes/archive_mail_bottom.php');
+
+
+      if ($fixed_archive_mail_plugin_is_in_use_in_SM_1_4_x
+       && $archive_mail_button_has_been_printed)
          echo '&nbsp;';
       else
          echo '<tr width="100%"><td align="right">';
 
+
+      bindtextdomain('preview_pane', SM_PATH . 'plugins/preview_pane/locale');
+      textdomain('preview_pane');
+
       echo '<input type="button" value="' . _("Clear Preview") 
          . '" onClick="parent.bottom.document.location=\'' . SM_PATH 
          . 'plugins/preview_pane/empty_frame.php\'">'
          . '</td></tr>';
+
+      bindtextdomain('squirrelmail', SM_PATH . 'locale');
+      textdomain('squirrelmail');
+
    }
 
 }
 
 
+/**
+  * Points message targets to open in the preview pane
+  * (and possibly refresh message list as well)
+  *
+  */
 function preview_pane_change_message_target_do($args)
 {
 
-   global $data_dir, $username, $_SERVER;
+   global $data_dir, $username;
+   sqgetGlobalVar('REQUEST_URI', $request_uri, SQ_SERVER);
 
    if (getPref($data_dir, $username, 'use_previewPane', 0) == 1) 
    {
       $pp_refresh_message_list = getPref($data_dir, $username, 'pp_refresh_message_list', 0);
       $ret = ' TARGET="bottom" ';
       if ($pp_refresh_message_list)
-         $ret .= ' onClick="document.location=\'' . $_SERVER['REQUEST_URI'] . '\'" ';
+         $ret .= ' onClick="document.location=\'' . $request_uri . '\'" ';
       return $ret;
    }
 
 }
 
 
+/**
+  * Helper function that allows preview_pane_check_frames_do() to
+  * know what kind of send action was actually occuring.
+  *
+  */
 function preview_pane_compose_send_do()
 {
    global $action, $pp_action;
@@ -232,18 +290,28 @@ function preview_pane_change_message_display_do($source)
          $menu_row = $source[1];
 
          // retarget message list link to top frame (in $nav_row)
-         // and recode the target of the delete links to delete 
-         // message in top frame and clear out the bottom frame (in $menu_row)
+         // and recode the target of the delete links to delete
+         // message in top frame and move to next/prev messge in 
+         // bottom frame (or clear out the bottom frame if the
+         // delete button was pressed) 
          //
-         list($nav_row, $menu_row) = preg_replace(array(
-                                       '/(href="[^"]*?right_main.*?)>/',
-                                       '/href="([^"]*?delete_message.*?)"(.*?)>/'),
-                                 array(
-                                       '$1 target="right">', 
-                                       'href="$1" onClick="parent.right.document.location=\'$1\'; document.location=\'' . SM_PATH . 'plugins/preview_pane/empty_frame.php\'; return false;"$2>'),
-                                 array($nav_row, $menu_row));
+         // (the delete & prev, delete & next, and the message list
+         // links are in $nav_row, the delete button is in $menu_row)
+         //
+         $nav_row = preg_replace(array('/&amp;delete_id=(\d+)"/', '/(href="[^"]*?right_main\.php\?.*?)>/'),
 
-// that last line was:    'href="' . rand() . '" onClick="parent.right.document.location=\'$1\'; document.location=\'' . SM_PATH . 'plugins/preview_pane/empty_frame.php\'; return false;"$2>'),
+// WHY WHY WHY can't I access form widgets in the deleteMessageForm by using 
+// "document.deleteMessageForm" instead of "document.forms[1]"????  Something
+// is fishy here
+//
+                                 array('" onClick="if (parent.right) { document.forms[1].submit(); }"', '$1 target="right">'),
+
+                                 $nav_row);
+
+
+         $menu_row = preg_replace(array('/deleteMessageForm"(.*?)>/', '/(SUBMIT.*?name)="delete"/'),
+                                  array('deleteMessageForm" target="right" onSubmit="document.location=\'' . SM_PATH . 'plugins/preview_pane/empty_frame.php\'" $1><input type="hidden" name="delete" value="1" />', '$1="delBtn"'),
+                                  $menu_row);
 
          return array($nav_row, $menu_row);
       }
@@ -261,8 +329,8 @@ function preview_pane_change_message_display_do($source)
             '/(<a.*?right_main.*?)>(.*?)href="(.*?delete_message.*?)"(.*?)<\/a>/', 
 
             '$1 target="right">$2href="$3'     // was:  ' . rand() 
-            . '" onClick="parent.right.document.location=\'$3\'; document.location=\'' 
-            . SM_PATH . 'plugins/preview_pane/empty_frame.php\'; return false;"$4</a>',
+            . '" onClick="if (parent.right) {parent.right.document.location=\'$3\'; document.location=\'' 
+            . SM_PATH . 'plugins/preview_pane/empty_frame.php\'; return false;}"$4</a>',
 
             $source);
 
